/* GCompris - drawletters_dataset.js
* Copyright (C) 2016 Nitish Chauhan <nitish.nc18@gmail.com>

* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, see <https://www.gnu.org/licenses/>.
*/

.import GCompris 1.0 as GCompris //for ApplicationInfo
.import "qrc:/gcompris/src/core/core.js" as Core

function get() {
    return [
    {
        "imageName1": "paper.svg",
        "imageName2": "A1.svg",
        "coordinates": [[278,58],[260,100],[242,144],[225,187],[207,230],[189,276],[171,316],[154,359],[136,402],[278,58],[296,104],[314,144],[332,187],[350,230],[368,276],[386,316],[403,359],[420,402],[187,286],[235,286],[282,286],[330,286],[378,286]],
        "coordinates2": [1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,3,3,3,3,3],
        "sound": GCompris.ApplicationInfo.getAudioFilePath("voices-$CA/$LOCALE/alphabet/"+ Core.getSoundFilenamForChar("a"))
    },
    {
        "imageName1": "paper.svg",
        "imageName2": "B1.svg",
        "coordinates": [[190,59],[190,93],[190,126],[190,165],[190,212],[190,263],[190,308],[190,342],[190,375],[190,409],[223,77],[262,77],[300,78],[340,80],[384,91],[417,114],[433,154],[427,194],[388,226],[360,235],[328,242],[291,240],[262,235],[234,234],[223,234],[251,246],[288,248],[322,248],[358,249],[394,263],[427,291],[440,322],[441,357],[417,390],[375,406],[346,411],[307,413],[267,413],[244,413],[215,409]],
        "coordinates2": [1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2],
        "sound": GCompris.ApplicationInfo.getAudioFilePath("voices-$CA/$LOCALE/alphabet/"+ Core.getSoundFilenamForChar("b"))
    },
    {
        "imageName1": "paper.svg",
        "imageName2": "C1.svg",
        "coordinates": [[435,160],[420,135],[391,110],[353,91],[318,86],[289,86],[255,93],[220,108],[184,136],[162,166],[147,211],[148,249],[157,282],[175,314],[198,340],[233,360],[278,372],[318,372],[361,362],[406,342],[427,315],[442,284]],
        "sound": GCompris.ApplicationInfo.getAudioFilePath("voices-$CA/$LOCALE/alphabet/"+ Core.getSoundFilenamForChar("c"))
    },
    {
        "imageName1": "paper.svg",
        "imageName2": "D1.svg",
        "coordinates": [[110,67],[110,98],[110,132],[110,173],[110,220],[110,267],[110,305],[110,347],[110,383],[110,410],[146,73],[184,78],[219,80],[255,81],[292,85],[328,90],[373,100],[408,118],[434,144],[456,174],[471,220],[475,268],[467,315],[437,356],[398,385],[346,401],[307,406],[260,409],[219,409],[190,409],[157,407]],
        "coordinates2": [1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2],
        "sound": GCompris.ApplicationInfo.getAudioFilePath("voices-$CA/$LOCALE/alphabet/"+ Core.getSoundFilenamForChar("d"))
    },
    {
        "imageName1": "paper.svg",
        "imageName2": "E1.svg",
        "coordinates": [[161,62],[161,95],[161,133],[161,175],[161,216],[161,256],[161,296],[161,336],[161,377],[186,78],[212,78],[242,78],[274,78],[304,78],[335,78],[368,78],[405,78],[186,220],[217,220],[253,220],[289,220],[322,220],[353,220],[390,220],[193,366],[222,366],[252,366],[285,366],[313,366],[346,366],[377,366],[408,366]],
        "coordinates2": [1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,4,4,4,4,4,4,4,4],
        "sound": GCompris.ApplicationInfo.getAudioFilePath("voices-$CA/$LOCALE/alphabet/"+ Core.getSoundFilenamForChar("e"))
    },
    {
        "imageName1": "paper.svg",
        "imageName2": "F1.svg",
        "coordinates": [[176,81],[176,107],[176,140],[176,180],[176,215],[176,256],[176,304],[176,339],[176,379],[176,415],[201,96],[230,96],[257,96],[291,96],[318,96],[343,96],[373,96],[411,96],[204,249],[227,249],[256,249],[292,249],[324,249],[357,249],[391,249]],
        "coordinates2": [1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3],
        "sound": GCompris.ApplicationInfo.getAudioFilePath("voices-$CA/$LOCALE/alphabet/"+ Core.getSoundFilenamForChar("f"))
    },
    {
        "imageName1": "paper.svg",
        "imageName2": "G1.svg",
        "coordinates": [[446,147],[434,124],[411,97],[383,82],[347,70],[317,66],[275,73],[242,86],[208,107],[183,136],[164,172],[161,206],[165,256],[179,297],[206,328],[238,350],[282,366],[320,369],[362,366],[397,355],[428,344],[456,315],[455,288],[455,262],[455,234],[339,235],[369,235],[395,235],[423,235]],
        "coordinates2": [1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2],
        "sound": GCompris.ApplicationInfo.getAudioFilePath("voices-$CA/$LOCALE/alphabet/"+ Core.getSoundFilenamForChar("g"))
    },
    {
        "imageName1": "paper.svg",
        "imageName2": "H1.svg",
        "coordinates": [[165,71],[165,107],[165,160],[165,194],[165,235],[165,267],[165,310],[165,344],[165,379],[165,400],[182,228],[206,230],[240,230],[268,230],[296,230],[325,230],[350,230],[379,230],[404,230],[416,75],[416,104],[416,136],[416,169],[416,213],[416,262],[416,299],[416,340],[416,368],[416,393]],
        "coordinates2": [1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,3],
        "sound": GCompris.ApplicationInfo.getAudioFilePath("voices-$CA/$LOCALE/alphabet/"+ Core.getSoundFilenamForChar("h"))
    },
    {
        "imageName1": "paper.svg",
        "imageName2": "I1.svg",
        "coordinates": [[248,78],[248,106],[248,148],[248,184],[248,220],[248,251],[248,282],[248,320],[248,357],[248,391],[248,409]],
        "sound": GCompris.ApplicationInfo.getAudioFilePath("voices-$CA/$LOCALE/alphabet/"+ Core.getSoundFilenamForChar("i"))
    },
    {
        "imageName1": "paper.svg",
        "imageName2": "J1.svg",
        "coordinates": [[369,71],[369,102],[369,136],[369,179],[369,224],[369,270],[369,306],[368,346],[348,375],[311,391],[277,394],[241,384],[213,348],[205,321]],
        "sound": GCompris.ApplicationInfo.getAudioFilePath("voices-$CA/$LOCALE/alphabet/"+ Core.getSoundFilenamForChar("j"))
    },
    {
        "imageName1": "paper.svg",
        "imageName2": "K1.svg",
        "coordinates": [[160,64],[160,102],[160,146],[160,190],[160,240],[160,281],[160,325],[160,366],[160,402],[160,402],[160,437],[186,273],[224,246],[257,219],[285,195],[315,169],[346,144],[375,124],[411,95],[444,68],[286,224],[310,257],[333,289],[366,318],[387,348],[411,373],[434,406],[459,434]],
        "coordinates2": [1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3],
        "sound": GCompris.ApplicationInfo.getAudioFilePath("voices-$CA/$LOCALE/alphabet/"+ Core.getSoundFilenamForChar("k"))
    },
    {
        "imageName1": "paper.svg",
        "imageName2": "L1.svg",
        "coordinates": [[177,64],[177,110],[177,158],[177,206],[177,264],[177,315],[177,365],[177,406],[177,420],[211,420],[245,420],[286,420],[326,420],[361,420],[404,420]],
        "sound": GCompris.ApplicationInfo.getAudioFilePath("voices-$CA/$LOCALE/alphabet/"+ Core.getSoundFilenamForChar("l"))
    },
    {
        "imageName1": "paper.svg",
        "imageName2": "M1.svg",
        "coordinates": [[144,73],[144,106],[144,148],[144,194],[144,227],[144,263],[144,297],[144,337],[144,377],[144,413],[147,75],[174,80],[186,103],[198,137],[211,175],[222,204],[234,234],[249,263],[259,291],[274,325],[286,360],[302,393],[311,413],[325,379],[339,344],[354,311],[364,280],[376,246],[387,217],[401,184],[413,150],[426,115],[446,82],[462,114],[462,142],[462,171],[462,201],[462,233],[462,266],[462,306],[462,340],[462,372],[462,405]],
        "coordinates2": [1,1,1,1,1,1,1,1,1,1],
        "sound": GCompris.ApplicationInfo.getAudioFilePath("voices-$CA/$LOCALE/alphabet/"+ Core.getSoundFilenamForChar("m"))
    },
    {
        "imageName1": "paper.svg",
        "imageName2": "N1.svg",
        "coordinates": [[186,96],[186,127],[186,146],[186,172],[186,195],[186,226],[186,255],[186,279],[186,302],[186,324],[186,349],[186,374],[186,96],[206,118],[219,130],[234,150],[250,168],[265,185],[280,201],[295,223],[313,243],[327,260],[345,287],[368,312],[390,334],[410,349],[431,368],[431,343],[431,328],[431,296],[431,267],[431,245],[431,220],[431,194],[431,163],[431,137],[431,111],[431,96]],
        "coordinates2": [1,1,1,1,1,1,1,1,1,1,1,1,1],
        "sound": GCompris.ApplicationInfo.getAudioFilePath("voices-$CA/$LOCALE/alphabet/"+ Core.getSoundFilenamForChar("n"))
    },
    {
        "imageName1": "paper.svg",
        "imageName2": "O1.svg",
        "coordinates": [[291,71],[270,66],[228,78],[193,96],[165,122],[144,155],[131,195],[118,246],[125,292],[140,331],[160,364],[184,394],[215,411],[246,424],[284,430],[322,430],[357,415],[394,394],[426,369],[441,335],[453,302],[457,251],[452,209],[440,168],[417,132],[393,108],[360,89],[326,77]],
        "sound": GCompris.ApplicationInfo.getAudioFilePath("voices-$CA/$LOCALE/alphabet/"+ Core.getSoundFilenamForChar("o"))
    },
    {
        "imageName1": "paper.svg",
        "imageName2": "P1.svg",
        "coordinates":  [[154,56],[154,99],[154,132],[154,172],[154,212],[154,273],[154,324],[154,361],[154,400],[154,435],[169,73],[212,73],[248,74],[286,74],[324,78],[371,81],[420,96],[457,121],[477,161],[480,209],[455,249],[412,267],[380,273],[344,277],[308,277],[271,278],[235,275],[208,277],[184,277]],
        "coordinates2": [1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2],
        "sound": GCompris.ApplicationInfo.getAudioFilePath("voices-$CA/$LOCALE/alphabet/"+ Core.getSoundFilenamForChar("p"))
    },
    {
        "imageName1": "paper.svg",
        "imageName2": "Q1.svg",
        "coordinates": [[321,107],[299,99],[271,107],[233,120],[195,148],[172,188],[160,226],[161,270],[175,303],[193,332],[222,360],[260,376],[292,382],[346,382],[390,368],[423,347],[455,308],[466,270],[464,233],[456,193],[430,153],[393,122],[358,108],[329,324],[360,337],[390,350],[413,366],[444,383],[473,397],[492,406]],
        "coordinates2": [1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2],
        "sound": GCompris.ApplicationInfo.getAudioFilePath("voices-$CA/$LOCALE/alphabet/"+ Core.getSoundFilenamForChar("q"))
    },
    {
        "imageName1": "paper.svg",
        "imageName2": "R1.svg",
        "coordinates": [[143,86],[146,120],[146,160],[146,202],[146,246],[146,300],[146,344],[146,391],[146,428],[177,99],[212,100],[246,100],[286,100],[329,100],[377,118],[415,147],[428,191],[412,238],[364,256],[311,266],[268,266],[228,263],[202,259],[177,260],[202,277],[234,275],[273,280],[308,292],[339,322],[368,351],[387,379],[415,405],[437,428]],
        "coordinates2": [1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2],
        "sound": GCompris.ApplicationInfo.getAudioFilePath("voices-$CA/$LOCALE/alphabet/"+ Core.getSoundFilenamForChar("r"))
    },
    {
        "imageName1": "paper.svg",
        "imageName2": "S1.svg",
        "coordinates": [[448,175],[434,148],[404,125],[366,110],[320,103],[277,104],[245,117],[202,132],[179,162],[176,200],[204,223],[248,237],[281,246],[325,253],[382,264],[423,277],[452,304],[456,343],[423,371],[382,388],[329,394],[284,390],[240,383],[205,368],[171,346],[148,307]],
        "sound": GCompris.ApplicationInfo.getAudioFilePath("voices-$CA/$LOCALE/alphabet/"+ Core.getSoundFilenamForChar("s"))
    },
    {
        "imageName1": "paper.svg",
        "imageName2": "T1.svg",
        "coordinates": [[150,85],[194,85],[233,85],[271,85],[313,85],[350,85],[394,85],[434,85],[304,111],[304,153],[304,186],[304,222],[304,262],[304,303],[304,344],[304,384],[304,424]],
        "coordinates2": [1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2],
        "sound": GCompris.ApplicationInfo.getAudioFilePath("voices-$CA/$LOCALE/alphabet/"+ Core.getSoundFilenamForChar("t"))
    },
    {
        "imageName1": "paper.svg",
        "imageName2": "U1.svg",
        "coordinates": [[151,77],[151,118],[151,160],[151,195],[151,234],[151,275],[151,311],[171,351],[198,380],[242,400],[278,404],[320,402],[360,388],[395,369],[423,329],[430,284],[430,237],[430,201],[430,168],[430,136],[430,104],[430,78]],
        "sound": GCompris.ApplicationInfo.getAudioFilePath("voices-$CA/$LOCALE/alphabet/"+ Core.getSoundFilenamForChar("u"))
    },
    {
        "imageName1": "paper.svg",
        "imageName2": "V1.svg",
        "coordinates": [[188,110],[198,134],[205,156],[214,183],[224,207],[230,228],[239,254],[249,277],[260,303],[272,335],[284,359],[298,387],[315,352],[325,321],[341,280],[356,242],[367,212],[382,173],[395,143],[405,111]],
        "sound": GCompris.ApplicationInfo.getAudioFilePath("voices-$CA/$LOCALE/alphabet/"+ Core.getSoundFilenamForChar("v"))
    },
    {
        "imageName1": "paper.svg",
        "imageName2": "W1.svg",
        "coordinates": [[124,110],[134,142],[144,175],[154,207],[164,240],[174,272],[184,305],[194,337],[204,370],[214,337],[224,305],[234,272],[244,240],[254,207],[264,175],[274,142],[284,110],[294,142],[304,175],[314,207],[324,240],[334,272],[344,305],[354,337],[364,370],[374,337],[384,305],[394,272],[404,240],[414,207],[424,175],[434,142],[444,110]],
        "sound": GCompris.ApplicationInfo.getAudioFilePath("voices-$CA/$LOCALE/alphabet/"+ Core.getSoundFilenamForChar("w"))
    },
    {
        "imageName1": "paper.svg",
        "imageName2": "X1.svg",
        "coordinates": [[173,93],[191,115],[206,140],[224,161],[244,184],[267,212],[295,240],[313,267],[333,295],[355,321],[379,348],[400,373],[423,400],[424,92],[404,125],[380,153],[357,180],[332,211],[311,235],[277,275],[252,303],[226,333],[204,358],[186,379],[161,408]],
        "coordinates2": [1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,2,2,2],
        "sound": GCompris.ApplicationInfo.getAudioFilePath("voices-$CA/$LOCALE/alphabet/"+ Core.getSoundFilenamForChar("x"))
    },
    {
        "imageName1": "paper.svg",
        "imageName2": "Y1.svg",
        "coordinates": [[165,91],[180,122],[200,154],[219,183],[235,213],[260,253],[285,292],[411,99],[388,136],[375,158],[360,186],[343,211],[331,234],[308,267],[289,303],[289,339],[289,371],[289,395],[289,420],[289,446]],
        "coordinates2": [1,1,1,1,1,1,1,2,2,2,2,2,2,2,3,3,3,3,3,3],
        "sound": GCompris.ApplicationInfo.getAudioFilePath("voices-$CA/$LOCALE/alphabet/"+ Core.getSoundFilenamForChar("y"))
    },
    {
        "imageName1": "paper.svg",
        "imageName2": "Z1.svg",
        "coordinates": [[180,146],[219,146],[252,146],[289,146],[328,146],[368,146],[413,146],[455,146],[427,179],[398,206],[375,228],[350,251],[321,274],[286,303],[256,332],[217,358],[177,384],[217,382],[253,384],[289,384],[320,384],[357,384],[394,384],[431,384],[475,384]],
        "sound": GCompris.ApplicationInfo.getAudioFilePath("voices-$CA/$LOCALE/alphabet/"+ Core.getSoundFilenamForChar("z"))
    }
    ]
}
